import YAML from "yaml";
import z from "zod";

const BindingSchema = z.object({
  id: z.string(),
  playbill: z.string().default("Unnamed playbill"),
  author: z.string().optional(),
  version: z.number(),
  files: z.array(z.string()).default(["**/*.yaml"]),
});

type Binding = z.infer<typeof BindingSchema>;

export async function loadBindingFile(filePath: string): Promise<Binding> {
  const file = Bun.file(filePath);
  const text = await file.text();
  const parsed = YAML.parse(text);
  return BindingSchema.parse(parsed);
}
