import type { ZodSchema } from "zod";

const directiveHandlers = {
  dmg: (amount = "1", type = "physical") => {
    return `<em class='dmg ${type}'>${amount}</em>`;
  },
};

type DirectiveHandler = (...args: string[]) => string;

function processCommands(
  text: string,
  handlers: { [key: string]: DirectiveHandler },
): string {
  const commandPattern = /\{(\w+):([^}]+)\}/g;

  return text.replace(commandPattern, (match, command, args) => {
    const handler = handlers[command];
    if (handler) {
      const parsedArgs = [];
      let currentArg = "";
      let inQuotes = false;

      for (let i = 0; i < args.length; i++) {
        const char = args[i];
        if (char === '"' && (i === 0 || args[i - 1] !== "\\")) {
          inQuotes = !inQuotes;
        } else if (char === "," && !inQuotes) {
          parsedArgs.push(currentArg.trim().replace(/^"|"$/g, ""));
          currentArg = "";
        } else {
          currentArg += char;
        }
      }
      parsedArgs.push(currentArg.trim().replace(/^"|"$/g, ""));

      return handler(...parsedArgs);
    }
    return match;
  });
}

export async function processLang(input: string): Promise<string> {
  const lines = input.split("\n");
  const processedLines: string[] = [];
  for (const line of lines) {
    const processed = processCommands(line, directiveHandlers);
    processedLines.push(processed);
  }

  return processedLines.join("\n");
}
